@@ -7,7 +7,7 @@ use crate::{
     strings, ui,
 };
 
-use crossterm::event::{Event, KeyCode};
+use crossterm::event::{Event, KeyCode, KeyModifiers};
 use std::borrow::Cow;
 use strings::commands;
 use tui::{
@@ -26,7 +26,7 @@ pub struct ResetComponent {
 }
 
 impl DrawableComponent for ResetComponent {
-    fn draw<B: Backend>(&self, f: &mut Frame<B>, _rect: Rect) {
+    fn draw<B: Backend>(&mut self, f: &mut Frame<B>, _rect: Rect) {
         if self.visible {
             let mut txt = Vec::new();
             txt.push(Text::Styled(
@@ -74,16 +74,24 @@ impl Component for ResetComponent {
         if self.visible {
             if let Event::Key(e) = ev {
                 return match e.code {
+                    KeyCode::Char(c) => {
+                        // ignore and early out on ctrl+c
+                        !(c == 'c'
+                            && e.modifiers
+                                .contains(KeyModifiers::CONTROL))
+                    }
+
                     KeyCode::Esc => {
                         self.hide();
                         true
                     }
+
                     KeyCode::Enter => {
                         self.confirm();
                         true
                     }
 
-                    _ => false,
+                    _ => true,
                 };
             }
         }
